@@ -6,6 +6,7 @@ from typing_extensions import Annotated
 from napari_plugin_engine import napari_hook_implementation
 from napari.layers import Image, Labels, Layer
 from napari_tools_menu import register_function, register_action
+import napari
 
 LayerInput = Annotated[Layer, {"label": "Image"}]
 
@@ -14,9 +15,14 @@ def napari_experimental_provide_function():
     return [convert_to_2d_timelapse]
 
 @register_function(menu="Utilities > Convert 3D stack to 2D timelapse (time-slicer)")
-def convert_to_2d_timelapse(layer : LayerInput) -> Layer:
+def convert_to_2d_timelapse(layer : LayerInput, viewer:napari.Viewer = None) -> Layer:
     if isinstance(layer, Labels):
-        return Labels(np.expand_dims(layer.data, axis=1), name="2d+t " + layer.name)
+        result = Labels(layer.data[:,np.newaxis,:,:], name="2d+t " + layer.name)
     else:
-        return Image(np.expand_dims(layer.data, axis=1), name="2d+t " + layer.name)
+        result = Image(layer.data[:,np.newaxis,:,:], name="2d+t " + layer.name)
 
+    if viewer is not None:
+        step = viewer.dims.current_step
+        step = (step[0], 0, step[1], step[2])
+        viewer.dims.current_step = step
+    return result
